@@ -1,6 +1,4 @@
-/* Clearlooks theme engine
- * Copyright (C) 2006 Richard Stellingwerff
- * Copyright (C) 2006 Daniel Borgman
+/* Clearlooks Inverted style
  * Copyright (C) 2007 Andrea Cimitan
  *
  * This library is free software; you can redistribute it and/or
@@ -742,10 +740,10 @@ clearlooks_inverted_draw_list_view_header (cairo_t *cr,
 		separator.horizontal = FALSE;
 		
 		if (params->ltr)
-			params->style_functions->draw_separator (cr, &colors->shade[3], params, &separator,
+			params->style_functions->draw_separator (cr, colors, params, &separator,
 			                                         width-1.5, 4.0, 2, height-8.0);
 		else
-			params->style_functions->draw_separator (cr, &colors->shade[3], params, &separator,
+			params->style_functions->draw_separator (cr, colors, params, &separator,
 			                                         1.5, 4.0, 2, height-8.0);
 	}
 }
